QWED Test Report - 2025-12-01

# 🛡️ QWED Comprehensive Test Audit

Generated: 2025-12-01 09:55:24

GOOD
Total Tests
9
Passed
8
Failed
1
Pass Rate
88.9%
Duration
5.7s

## 📊 Results by Priority

Priority | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
CRITICAL | 3 | 3 | 0 | 100.0%
HIGH | 5 | 4 | 1 | 80.0%
MEDIUM | 1 | 1 | 0 | 100.0%

## 🔧 Results by Engine

Engine | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
MATH | 9 | 8 | 1 | 88.9%

## ❌ Failed Tests (1)

### Detect order of operations ambiguity

Engine: math Priority: HIGH ID: MATH_AMB_001